==> tellico_3.3.5.orig.tar.xz: tellico-3.3.5/src/utils/lccnvalidator.h <==
/***************************************************************************
    Copyright (C) 2008-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_LCCNVALIDATOR_H
#define TELLICO_LCCNVALIDATOR_H

#include <QValidator>

namespace Tellico {

/**
 * Library of Congress Control Number validator
 *
 * see https://www.loc.gov/marc/lccn_structure.html
 *
 * These are all valid
 * - 89-456
 * - 2001-1114
 * - gm 71-2450
 */
class LCCNValidator : public QRegExpValidator {
Q_OBJECT

public:
  LCCNValidator(QObject* parent = nullptr);

  /**
   * Returns the formalized version as dictated by LOC search
   * https://catalog.loc.gov/vwebv/ui/en_US/htdocs/help/searchBrowse.html
   */
  static QString formalize(const QString& value);
};

}
#endif

==> tellico_4.1.4.orig.tar.xz: tellico-4.1.4/src/utils/lccnvalidator.h <==
/***************************************************************************
    Copyright (C) 2008-2020 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_LCCNVALIDATOR_H
#define TELLICO_LCCNVALIDATOR_H

#include <QValidator>

namespace Tellico {

/**
 * Library of Congress Control Number validator
 *
 * see https://www.loc.gov/marc/lccn_structure.html
 *
 * These are all valid
 * - 89-456
 * - 2001-1114
 * - gm 71-2450
 */
class LCCNValidator : public QRegularExpressionValidator {
Q_OBJECT

public:
  LCCNValidator(QObject* parent = nullptr);

  /**
   * Returns the formalized version as dictated by LOC search
   * https://catalog.loc.gov/vwebv/ui/en_US/htdocs/help/searchBrowse.html
   */
  static QString formalize(const QString& value);
};

}
#endif
